upgrades

package
v0.0.0-...-330a102 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConnectCaches

func ConnectCaches(user, adminPasswordSource, sourceIp string, sourceClient, targetClient api.Infinispan, logger logr.Logger, targetVersion semver.Version) error

ConnectCaches Connects caches from a cluster (target) to another (source) via Remote Stores. Caches are created in the target cluster if needed.

func SyncCaches

func SyncCaches(sourceClient, targetClient api.Infinispan, logger logr.Logger) error

SyncCaches Do a sync data operation for each cache in a cluster

Types

This section is empty.

Jump to