Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectCaches ¶
func ConnectCaches(user, adminPasswordSource, sourceIp string, sourceClient, targetClient api.Infinispan, logger logr.Logger, targetVersion semver.Version) error
ConnectCaches Connects caches from a cluster (target) to another (source) via Remote Stores. Caches are created in the target cluster if needed.
func SyncCaches ¶
func SyncCaches(sourceClient, targetClient api.Infinispan, logger logr.Logger) error
SyncCaches Do a sync data operation for each cache in a cluster
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.